==> pyomop-5.2.0.tar.gz: pyomop-5.2.0/CHANGELOG.md <==
# Changelog

## [Unreleased](https://github.com/dermatologist/pyomop/tree/HEAD)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/5.1.0...HEAD)

**Merged pull requests:**

- Feature/fhir to omop 2 [\#228](https://github.com/dermatologist/pyomop/pull/228) ([dermatologist](https://github.com/dermatologist))
- Feature/docker db [\#225](https://github.com/dermatologist/pyomop/pull/225) ([dermatologist](https://github.com/dermatologist))
- feat: update CLI options and add version support; introduce test for … [\#224](https://github.com/dermatologist/pyomop/pull/224) ([dermatologist](https://github.com/dermatologist))
- Feature/new model [\#223](https://github.com/dermatologist/pyomop/pull/223) ([dermatologist](https://github.com/dermatologist))
- Feature/refactor 1 [\#222](https://github.com/dermatologist/pyomop/pull/222) ([dermatologist](https://github.com/dermatologist))
- build: update Python version to 3.11 in Dockerfile and devcontainer.j… [\#221](https://github.com/dermatologist/pyomop/pull/221) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump astral-sh/setup-uv from 5 to 6 [\#220](https://github.com/dermatologist/pyomop/pull/220) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/llm update 1 [\#219](https://github.com/dermatologist/pyomop/pull/219) ([dermatologist](https://github.com/dermatologist))
- Feature/pr new 1 [\#218](https://github.com/dermatologist/pyomop/pull/218) ([dermatologist](https://github.com/dermatologist))
- refactor: clean up code formatting and remove unnecessary newlines [\#204](https://github.com/dermatologist/pyomop/pull/204) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump jinja2 from 3.1.4 to 3.1.5 [\#200](https://github.com/dermatologist/pyomop/pull/200) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps-dev\): bump wheel from 0.37.1 to 0.45.1 [\#195](https://github.com/dermatologist/pyomop/pull/195) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/update deps 1 [\#194](https://github.com/dermatologist/pyomop/pull/194) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/setup-python from 5.0.0 to 5.3.0 [\#190](https://github.com/dermatologist/pyomop/pull/190) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump certifi from 2023.7.22 to 2024.7.4 [\#178](https://github.com/dermatologist/pyomop/pull/178) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump jinja2 from 3.1.3 to 3.1.4 [\#169](https://github.com/dermatologist/pyomop/pull/169) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump requests from 2.31.0 to 2.32.2 [\#168](https://github.com/dermatologist/pyomop/pull/168) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump urllib3 from 1.26.18 to 1.26.19 [\#167](https://github.com/dermatologist/pyomop/pull/167) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump jinja2 from 3.0.1 to 3.1.3 [\#161](https://github.com/dermatologist/pyomop/pull/161) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/llm llama index 1 [\#159](https://github.com/dermatologist/pyomop/pull/159) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/setup-python from 2.3.1 to 5.0.0 [\#155](https://github.com/dermatologist/pyomop/pull/155) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/update deps 1 [\#151](https://github.com/dermatologist/pyomop/pull/151) ([dermatologist](https://github.com/dermatologist))
- SQLAlchemy \>2 fix \#6 [\#150](https://github.com/dermatologist/pyomop/pull/150) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/checkout from 3 to 4 [\#143](https://github.com/dermatologist/pyomop/pull/143) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump certifi from 2022.12.7 to 2023.7.22 [\#141](https://github.com/dermatologist/pyomop/pull/141) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump urllib3 from 1.26.6 to 1.26.18 [\#140](https://github.com/dermatologist/pyomop/pull/140) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump pygments from 2.10.0 to 2.15.0 [\#139](https://github.com/dermatologist/pyomop/pull/139) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump requests from 2.26.0 to 2.31.0 [\#138](https://github.com/dermatologist/pyomop/pull/138) ([dependabot[bot]](https://github.com/apps/dependabot))
- Update README.md [\#129](https://github.com/dermatologist/pyomop/pull/129) ([dermatologist](https://github.com/dermatologist))
- Update vocabulary.py [\#128](https://github.com/dermatologist/pyomop/pull/128) ([EthelEz](https://github.com/EthelEz))

## [5.1.0](https://github.com/dermatologist/pyomop/tree/5.1.0) (2025-06-22)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/5.0.0...5.1.0)

## [5.0.0](https://github.com/dermatologist/pyomop/tree/5.0.0) (2025-06-22)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.4.1...5.0.0)

## [4.4.1](https://github.com/dermatologist/pyomop/tree/4.4.1) (2025-05-29)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.4.0...4.4.1)

## [4.4.0](https://github.com/dermatologist/pyomop/tree/4.4.0) (2025-05-09)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.3.0...4.4.0)

## [4.3.0](https://github.com/dermatologist/pyomop/tree/4.3.0) (2024-07-11)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.2.0...4.3.0)

## [4.2.0](https://github.com/dermatologist/pyomop/tree/4.2.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.1.0...4.2.0)

## [4.1.0](https://github.com/dermatologist/pyomop/tree/4.1.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.0.0...4.1.0)

## [4.0.0](https://github.com/dermatologist/pyomop/tree/4.0.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.2.0...4.0.0)

## [3.2.0](https://github.com/dermatologist/pyomop/tree/3.2.0) (2023-01-20)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.1.0...3.2.0)

## [3.1.0](https://github.com/dermatologist/pyomop/tree/3.1.0) (2021-09-17)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.0.0...3.1.0)

## [3.0.0](https://github.com/dermatologist/pyomop/tree/3.0.0) (2020-10-23)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/2.0.0...3.0.0)

## [2.0.0](https://github.com/dermatologist/pyomop/tree/2.0.0) (2020-06-27)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.2.0...2.0.0)

## [1.2.0](https://github.com/dermatologist/pyomop/tree/1.2.0) (2020-05-23)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.1.1...1.2.0)

## [1.1.1](https://github.com/dermatologist/pyomop/tree/1.1.1) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.1.0...1.1.1)

## [1.1.0](https://github.com/dermatologist/pyomop/tree/1.1.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.0.0...1.1.0)

## [1.0.0](https://github.com/dermatologist/pyomop/tree/1.0.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/0.1.0...1.0.0)

## [0.1.0](https://github.com/dermatologist/pyomop/tree/0.1.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/c647331d8bcb13f0353f85a49ed552294631fee3...0.1.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*

==> pyomop-5.3.0.tar.gz: pyomop-5.3.0/CHANGELOG.md <==
# Changelog

## [Unreleased](https://github.com/dermatologist/pyomop/tree/HEAD)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/v5.2.1...HEAD)

**Merged pull requests:**

- Feature/hotfix 2 [\#229](https://github.com/dermatologist/pyomop/pull/229) ([dermatologist](https://github.com/dermatologist))
- Feature/fhir to omop 2 [\#228](https://github.com/dermatologist/pyomop/pull/228) ([dermatologist](https://github.com/dermatologist))
- Feature/docker db [\#225](https://github.com/dermatologist/pyomop/pull/225) ([dermatologist](https://github.com/dermatologist))
- feat: update CLI options and add version support; introduce test for … [\#224](https://github.com/dermatologist/pyomop/pull/224) ([dermatologist](https://github.com/dermatologist))
- Feature/new model [\#223](https://github.com/dermatologist/pyomop/pull/223) ([dermatologist](https://github.com/dermatologist))
- Feature/refactor 1 [\#222](https://github.com/dermatologist/pyomop/pull/222) ([dermatologist](https://github.com/dermatologist))
- build: update Python version to 3.11 in Dockerfile and devcontainer.j… [\#221](https://github.com/dermatologist/pyomop/pull/221) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump astral-sh/setup-uv from 5 to 6 [\#220](https://github.com/dermatologist/pyomop/pull/220) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/llm update 1 [\#219](https://github.com/dermatologist/pyomop/pull/219) ([dermatologist](https://github.com/dermatologist))
- Feature/pr new 1 [\#218](https://github.com/dermatologist/pyomop/pull/218) ([dermatologist](https://github.com/dermatologist))
- refactor: clean up code formatting and remove unnecessary newlines [\#204](https://github.com/dermatologist/pyomop/pull/204) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump jinja2 from 3.1.4 to 3.1.5 [\#200](https://github.com/dermatologist/pyomop/pull/200) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps-dev\): bump wheel from 0.37.1 to 0.45.1 [\#195](https://github.com/dermatologist/pyomop/pull/195) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/update deps 1 [\#194](https://github.com/dermatologist/pyomop/pull/194) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/setup-python from 5.0.0 to 5.3.0 [\#190](https://github.com/dermatologist/pyomop/pull/190) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump certifi from 2023.7.22 to 2024.7.4 [\#178](https://github.com/dermatologist/pyomop/pull/178) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump jinja2 from 3.1.3 to 3.1.4 [\#169](https://github.com/dermatologist/pyomop/pull/169) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump requests from 2.31.0 to 2.32.2 [\#168](https://github.com/dermatologist/pyomop/pull/168) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump urllib3 from 1.26.18 to 1.26.19 [\#167](https://github.com/dermatologist/pyomop/pull/167) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump jinja2 from 3.0.1 to 3.1.3 [\#161](https://github.com/dermatologist/pyomop/pull/161) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/llm llama index 1 [\#159](https://github.com/dermatologist/pyomop/pull/159) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/setup-python from 2.3.1 to 5.0.0 [\#155](https://github.com/dermatologist/pyomop/pull/155) ([dependabot[bot]](https://github.com/apps/dependabot))
- Feature/update deps 1 [\#151](https://github.com/dermatologist/pyomop/pull/151) ([dermatologist](https://github.com/dermatologist))
- SQLAlchemy \>2 fix \#6 [\#150](https://github.com/dermatologist/pyomop/pull/150) ([dermatologist](https://github.com/dermatologist))
- build\(deps\): bump actions/checkout from 3 to 4 [\#143](https://github.com/dermatologist/pyomop/pull/143) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump certifi from 2022.12.7 to 2023.7.22 [\#141](https://github.com/dermatologist/pyomop/pull/141) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump urllib3 from 1.26.6 to 1.26.18 [\#140](https://github.com/dermatologist/pyomop/pull/140) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump pygments from 2.10.0 to 2.15.0 [\#139](https://github.com/dermatologist/pyomop/pull/139) ([dependabot[bot]](https://github.com/apps/dependabot))
- build\(deps\): bump requests from 2.26.0 to 2.31.0 [\#138](https://github.com/dermatologist/pyomop/pull/138) ([dependabot[bot]](https://github.com/apps/dependabot))
- Update README.md [\#129](https://github.com/dermatologist/pyomop/pull/129) ([dermatologist](https://github.com/dermatologist))
- Update vocabulary.py [\#128](https://github.com/dermatologist/pyomop/pull/128) ([EthelEz](https://github.com/EthelEz))

## [v5.2.1](https://github.com/dermatologist/pyomop/tree/v5.2.1) (2025-08-16)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/v5.2.0...v5.2.1)

## [v5.2.0](https://github.com/dermatologist/pyomop/tree/v5.2.0) (2025-08-16)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/5.1.0...v5.2.0)

## [5.1.0](https://github.com/dermatologist/pyomop/tree/5.1.0) (2025-06-22)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/5.0.0...5.1.0)

## [5.0.0](https://github.com/dermatologist/pyomop/tree/5.0.0) (2025-06-22)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.4.1...5.0.0)

## [4.4.1](https://github.com/dermatologist/pyomop/tree/4.4.1) (2025-05-29)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.4.0...4.4.1)

## [4.4.0](https://github.com/dermatologist/pyomop/tree/4.4.0) (2025-05-09)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.3.0...4.4.0)

## [4.3.0](https://github.com/dermatologist/pyomop/tree/4.3.0) (2024-07-11)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.2.0...4.3.0)

## [4.2.0](https://github.com/dermatologist/pyomop/tree/4.2.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.1.0...4.2.0)

## [4.1.0](https://github.com/dermatologist/pyomop/tree/4.1.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/4.0.0...4.1.0)

## [4.0.0](https://github.com/dermatologist/pyomop/tree/4.0.0) (2023-11-19)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.2.0...4.0.0)

## [3.2.0](https://github.com/dermatologist/pyomop/tree/3.2.0) (2023-01-20)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.1.0...3.2.0)

## [3.1.0](https://github.com/dermatologist/pyomop/tree/3.1.0) (2021-09-17)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/3.0.0...3.1.0)

## [3.0.0](https://github.com/dermatologist/pyomop/tree/3.0.0) (2020-10-23)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/2.0.0...3.0.0)

## [2.0.0](https://github.com/dermatologist/pyomop/tree/2.0.0) (2020-06-27)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.2.0...2.0.0)

## [1.2.0](https://github.com/dermatologist/pyomop/tree/1.2.0) (2020-05-23)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.1.1...1.2.0)

## [1.1.1](https://github.com/dermatologist/pyomop/tree/1.1.1) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.1.0...1.1.1)

## [1.1.0](https://github.com/dermatologist/pyomop/tree/1.1.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/1.0.0...1.1.0)

## [1.0.0](https://github.com/dermatologist/pyomop/tree/1.0.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/0.1.0...1.0.0)

## [0.1.0](https://github.com/dermatologist/pyomop/tree/0.1.0) (2020-05-03)

[Full Changelog](https://github.com/dermatologist/pyomop/compare/c647331d8bcb13f0353f85a49ed552294631fee3...0.1.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
